MODULE par_gyre
   !!======================================================================
   !!                        ***  par_gyre  ***
   !! Ocean Domain parameter : rotated square bassin on a beta-plane at 1/jp_cfg 
   !!    degree resolution (GYRE configuration) and a 1D configuration case
   !!    NB: with AGRIF, values are not set as parameters
   !!======================================================================
   !! History :   9.0  !  2007-11  (G. Madec)  Original code from par_GYRE.h90
   !!----------------------------------------------------------------------
   !! NEMO/OPA 2.4 , LOCEAN-IPSL (2007) 
   !! $Header: $ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
#if defined key_gyre
   !!----------------------------------------------------------------------
   !!   'key_gyre'   :                                   GYRE configuration
   !!----------------------------------------------------------------------
   USE par_kind          ! kind parameters

   IMPLICIT NONE
   PUBLIC

# if defined key_agrif
   !------!!--------------------------------------------------------------
   !      !!   'key_agrif'   :                                       AGRIF 
   !------!!--------------------------------------------------------------

   ! Configuration, and domain size are not assigned to a parameter value
   !    as they are different in mother and children models
   INTEGER ::   cp_cfg, jp_cfg                          !: configuration id       (AGRIF case)
   INTEGER ::   jpidta, jpjdta, jpkdta                  !: input data size        (AGRIF case)
   INTEGER ::   jpiglo, jpjglo, jpk, jpizoom, jpjzoom   !: domain size and zoom   (AGRIF case)
   INTEGER ::   jperio, jpisl, jpnisl                   !: domain characteristics (AGRIF case)

# else
   !------!!--------------------------------------------------------------
   !      !!   Default       :                  no AGRIF: model parameters
   !------!!--------------------------------------------------------------

   ! Configuration name and resolution                 !!! *  GYRE  *
   CHARACTER (len=16), PARAMETER ::   cp_cfg = "gyre"   !: name of the configuration 
   INTEGER, PARAMETER            ::   jp_cfg = 1        !: resolution of the configuration (degrees)
   !                                                    !  control the size of GYRE configurations

   ! input data size                                   !!! *  size of all input files  *
   INTEGER, PARAMETER ::   jpidta  = 30 * jp_cfg + 2    !: 1st lateral dimension ( >= jpiglo )
   INTEGER, PARAMETER ::   jpjdta  = 20 * jp_cfg + 2    !: 2nd    "       "      ( >= jpjglo )
   INTEGER, PARAMETER ::   jpkdta  = 31                 !: number of levels      ( >= jpk    ) 

#  if defined key_cfg_1d
   !------------!!--------------------------------------------------------
   !            !!   'key_cfg_1d' :             1D configuration of MY_CFG
   !------------!!--------------------------------------------------------
   ! global domain size                                 !!! *  1D configuration  *
   INTEGER, PARAMETER ::   jpiglo  = 3                   !: 1st dimension of global domain --> i
   INTEGER, PARAMETER ::   jpjglo  = 3                   !: 2nd    "                  "    --> j
   INTEGER, PARAMETER ::   jpk     = jpkdta              !: number of vertical levels
   ! starting position of the zoom 
   INTEGER, PARAMETER ::   jpizoom =   16                !: left bottom (i,j) indices of the zoom
   INTEGER, PARAMETER ::   jpjzoom =   11                !: in data domain indices
   ! Domain characteristics
   INTEGER, PARAMETER ::   jperio  =   0                 !: lateral cond. type (between 0 and 6)
   INTEGER, PARAMETER ::   jpisl   =   0                 !: number of islands
   INTEGER, PARAMETER ::   jpnisl  =   0                 !: maximum number of points per island

#  else
   !------------!!--------------------------------------------------------
   !            !!   Default :                  Full global domain of GYRE
   !------------!!--------------------------------------------------------
   ! global domain size                                !!! *  global domain  *
   INTEGER, PARAMETER ::   jpiglo  = jpidta             !: 1st dimension of global domain --> i
   INTEGER, PARAMETER ::   jpjglo  = jpjdta             !: 2nd    "                  "    --> j
   INTEGER, PARAMETER ::   jpk     = jpkdta             !: number of vertical levels
   ! starting position of the zoom 
   INTEGER, PARAMETER ::   jpizoom =   1                !: left bottom (i,j) indices of the zoom
   INTEGER, PARAMETER ::   jpjzoom =   1                !: in data domain indices
   ! Domain characteristics
   INTEGER, PARAMETER ::   jperio  =   0                !: lateral cond. type (between 0 and 6)
   INTEGER, PARAMETER ::   jpisl   =   1                !: number of islands
   INTEGER, PARAMETER ::   jpnisl  =   1                !: maximum number of points per island
#  endif

# endif

   !!---------------------------------------------------------------------
   !! grid parameters for domhgr and domzgr
   !!---------------------------------------------------------------------
   ! Values set to pp_not_used indicates that this parameter is not used in THIS config.
   ! Values set to pp_to_be_computed  indicates that variables will be computed in domzgr
   REAL(wp), PARAMETER ::   pp_not_used       = 999999_wp   !: default value for "not used"
   REAL(wp), PARAMETER ::   pp_to_be_computed = 0._wp       !: default value for "to be computed"

   ! horizontal mesh (domhgr)
   !    Coefficients associated with the horizontal coordinate system (jphgr_msh /= 0 )
   INTEGER, PARAMETER ::   jphgr_msh = 5   !: type of horizontal mesh
   !                                       !  = 5  beta-plane with regular grid-spacing and rotated domain

   !   ppglam0 , ppgphi0: coordinates of the lower leftmost T point of the grid.
   !   The mercator grid starts only approximately at gphi0 because
   !   of the constraint that the equator be a T point.
   REAL(wp) ,PARAMETER ::   ppglam0  =    0.0_wp     !: longitude of first raw and column T-point (jphgr_msh=1)
   REAL(wp) ,PARAMETER ::   ppgphi0  =   29.0_wp     !: latitude  of first raw and column T-point (jphgr_msh=1)
   !                                                 !  latitude  of the Coriolis/Beta parameter  (jphgr_msh=2 or 3)
   REAL(wp) ,PARAMETER ::   ppe1_deg = pp_not_used   !: zonal      grid-spacing (degrees)
   REAL(wp) ,PARAMETER ::   ppe2_deg = pp_not_used   !: meridional grid-spacing (degrees)
   !
   REAL(wp) ,PARAMETER ::   ppe1_m   = pp_not_used   !: zonal      grid-spacing (meters )
   REAL(wp) ,PARAMETER ::   ppe2_m   = pp_not_used   !: meridional grid-spacing (meters )

   ! Vertical mesh (domzgr)
   !    parameter used in the analytical function defining the repartition of the level and their thickness
   REAL(wp), PARAMETER ::   ppsur = -2033.194295283385_wp     !: GYRE coefficients
   REAL(wp), PARAMETER ::   ppa0  =   155.8325369664153_wp    !:
   REAL(wp), PARAMETER ::   ppa1  =   146.3615918601890_wp    !:
   REAL(wp), PARAMETER ::   ppkth =    17.28520372419791_wp   !: (non dimensional): gives the approximate
   !                                                          !: layer number above which  stretching will
   !                                                          !: be maximum. Usually of order jpk/2.
   REAL(wp), PARAMETER ::   ppacr =     5.00000000000_wp      !: (non dimensional): stretching factor
   !                                                          !: for the grid. The highest zacr, the smallest
   !                                                          !: the stretching.
   !  If both ppa0 ppa1 and ppsur are specified to 0, then
   !  they are computed from ppdzmin, pphmax, ppkth, ppacr in dom_zgr
   REAL(wp), PARAMETER ::   ppdzmin = pp_not_used   !: vertical thickness of the top layer   [meters]
   REAL(wp), PARAMETER ::   pphmax  = pp_not_used   !: maximum depth of the ocean gdepw(jpk) [meters]

#else
   !!---------------------------------------------------------------------
   !!   default option  :                                     Empty module
   !!---------------------------------------------------------------------
#endif

   !!======================================================================
END MODULE par_gyre
